@@ -1,2 +1,2 @@
 from fake_useragent.fake import UserAgent
-from fake_useragent.build import rm_tmp
+from fake_useragent.utils import refresh
